@@ -1,5 +1,7 @@
 # tests for NumPy __array_function__ support
+import inspect
 import re
+import warnings
 from importlib.metadata import version
 
 import numpy as np
@@ -24,6 +26,13 @@ from unyt.unit_registry import UnitRegistry
 
 NUMPY_VERSION = Version(version("numpy"))
 
+
+VAR_POSITIONAL = inspect.Parameter.VAR_POSITIONAL
+VAR_KEYWORD = inspect.Parameter.VAR_KEYWORD
+POSITIONAL_ONLY = inspect.Parameter.POSITIONAL_ONLY
+KEYWORD_ONLY = inspect.Parameter.KEYWORD_ONLY
+POSITIONAL_OR_KEYWORD = inspect.Parameter.POSITIONAL_OR_KEYWORD
+
 # this is a subset of NOT_HANDLED_FUNCTIONS for which there's nothing to do
 # because they don't apply to (real) numeric types
 # or they work as expected out of the box
@@ -154,7 +163,7 @@ NOOP_FUNCTIONS = {
 
 
 if NUMPY_VERSION >= Version("2.0.0dev0"):
-    # the followin all work out of the box (tested)
+    # the following all work out of the box (tested)
     NOOP_FUNCTIONS |= {
         np.linalg.cross,
         np.linalg.diagonal,
@@ -175,6 +184,11 @@ if NUMPY_VERSION >= Version("2.0.0dev0"):
         np.vecdot,
     }
 
+if NUMPY_VERSION >= Version("2.1.0dev0"):
+    NOOP_FUNCTIONS |= {
+        np.unstack,
+    }
+
 # Functions for which behaviour is intentionally left to default
 IGNORED_FUNCTIONS = {
     np.i0,
@@ -184,35 +198,47 @@ IGNORED_FUNCTIONS = {
     np.savez_compressed,
 }
 
-
+# map subsets of deprecated functions to the version they were removed
+# so that we can drop the ones that are not present in any version we support
 DEPRECATED_FUNCTIONS = {
-    "alen",  # deprecated in numpy 1.18, removed in 1.22
-    "asscalar",  # deprecated in numpy 1.18, removed in 1.22
-    "fv",  # deprecated in numpy 1.18, removed in 1.20
-    "ipmt",  # deprecated in numpy 1.18, removed in 1.20
-    "irr",  # deprecated in numpy 1.18, removed in 1.20
-    "mirr",  # deprecated in numpy 1.18, removed in 1.20
-    "nper",  # deprecated in numpy 1.18, removed in 1.20
-    "npv",  # deprecated in numpy 1.18, removed in 1.20
-    "pmt",  # deprecated in numpy 1.18, removed in 1.20
-    "ppmt",  # deprecated in numpy 1.18, removed in 1.20
-    "pv",  # deprecated in numpy 1.18, removed in 1.20
-    "rank",  # deprecated in numpy 1.10, removed in 1.18
-    "rate",  # deprecated in numpy 1.18, removed in 1.20
-    "msort",  # deprecated in numpy 1.24
-    # numpy 1.25 deprecations
-    "product",
-    "cumproduct",
-    "round_",  # removed in 2.0
-    "sometrue",
-    "alltrue",
+    Version("1.20"): {
+        "fv",
+        "ipmt",
+        "irr",
+        "mirr",
+        "nper",
+        "npv",
+        "pmt",
+        "ppmt",
+        "pv",
+        "rate",
+    },
+    Version("1.22"): {
+        "alen",
+        "asscalar",
+    },
+    Version("2.0.0b1"): {
+        "msort",
+        "product",
+        "cumproduct",
+        "round_",
+        "sometrue",
+        "alltrue",
+    },
+    # functions that are deprecated but not yet removed in any known version
+    # should be added here
+    Version("999.999.999"): set(),
 }
 
 NOT_HANDLED_FUNCTIONS = NOOP_FUNCTIONS | UNSUPPORTED_FUNCTIONS | IGNORED_FUNCTIONS
 
-for func in DEPRECATED_FUNCTIONS:
-    if hasattr(np, func):
-        NOT_HANDLED_FUNCTIONS.add(getattr(np, func))
+with warnings.catch_warnings():
+    warnings.simplefilter("ignore", DeprecationWarning)
+    for removal_version, functions in DEPRECATED_FUNCTIONS.items():
+        if NUMPY_VERSION >= removal_version:
+            continue
+        for func in functions:
+            NOT_HANDLED_FUNCTIONS.add(getattr(np, func))
 
 
 def get_decorators(func):
@@ -930,7 +956,7 @@ def test_fft_shift(func):
 if NUMPY_VERSION >= Version("2.0.0dev0"):
     _trapezoid_func = np.trapezoid
 else:
-    _trapezoid_func = np.trapz
+    _trapezoid_func = np.trapz  # noqa: NPY201
 
 
 def test_trapezoid_no_x():
@@ -1202,16 +1228,25 @@ def test_broadcast_arrays():
 
 
 @pytest.mark.parametrize(
-    "func, args",
+    "func_name, args",
     [
-        (np.split, (3, 2)),
-        (np.dsplit, (3,)),
-        (np.hsplit, (2,)),
-        (np.vsplit, (1,)),
-        (np.array_split, (3,)),
+        ("split", (3, 2)),
+        ("dsplit", (3,)),
+        ("hsplit", (2,)),
+        ("vsplit", (1,)),
+        ("array_split", (3,)),
+        pytest.param(
+            "unstack",
+            (),
+            marks=pytest.mark.skipif(
+                NUMPY_VERSION < Version("2.1.0dev0"),
+                reason="np.unstack is new in NumPy 2.1",
+            ),
+        ),
     ],
 )
-def test_xsplit(func, args):
+def test_xsplit(func_name, args):
+    func = getattr(np, func_name)
     x = [
         [
             [
@@ -1404,7 +1439,7 @@ def test_eigvals(func):
 
 def test_savetxt(tmp_path):
     a = [1, 2, 3] * cm
-    with pytest.raises(
+    with pytest.warns(
         UserWarning,
         match=re.escape(
             "numpy.savetxt does not preserve units, "
@@ -1685,14 +1720,14 @@ def test_isin():
 def test_in1d_mixed_units():
     a = [1, 2, 3] * cm
     with pytest.raises(UnitInconsistencyError):
-        np.in1d([1, 2], a)
+        np.in1d([1, 2], a)  # noqa: NPY201
 
 
 @pytest.mark.filterwarnings("ignore:`in1d` is deprecated. Use `np.isin` instead.")
 def test_in1d():
     a = [1, 2, 3] * cm
     b = [1, 2] * cm
-    assert np.all(np.in1d(b, a))
+    assert np.all(np.in1d(b, a))  # noqa: NPY201
 
 
 def test_place_mixed_units():
@@ -1965,3 +2000,146 @@ def test_interp():
     res = np.interp(_x * cm, _xp * cm, _fp * K)
     assert type(res) is unyt_array
     assert res.units == K
+
+
+@pytest.mark.parametrize(
+    "target, helper",
+    sorted(
+        HANDLED_FUNCTIONS.items(),
+        key=lambda items: items[0].__name__,
+    ),
+    ids=lambda func: func.__name__,
+)
+class TestFunctionHelpersSignatureCompatibility:
+    """
+    Check that a helper function's signature is *at least* as flexible
+    as the helped (target) function's. E.g., any argument that is allowed positionally,
+    or as keyword, by the target must be re-exposed *somehow* by the helper.
+    We explicitly allow helper's signature to be *more* flexible than the target signature
+    by allowing *args and **kwargs catch-all arguments, which we use to limit code
+    duplication, and also help with forward and backward compatibility.
+    See https://github.com/astropy/astropy/issues/15703
+    """
+
+    # this test class is adapted from astropy.units
+
+    @staticmethod
+    def have_catchall_argument(parameters, kind) -> bool:
+        return any(p.kind is kind for p in parameters.values())
+
+    @staticmethod
+    def get_param_group(parameters, kinds: list) -> list[str]:
+        return [name for name, p in parameters.items() if p.kind in kinds]
+
+    def test_all_arguments_reexposed(self, target, helper):
+        try:
+            sig_target = inspect.signature(target)
+        except ValueError:
+            pytest.skip("Non Python function cannot be inspected at runtime")
+
+        params_target = sig_target.parameters
+        sig_helper = inspect.signature(helper)
+        params_helper = sig_helper.parameters
+
+        have_args_helper = self.have_catchall_argument(params_helper, VAR_POSITIONAL)
+        have_kwargs_helper = self.have_catchall_argument(params_helper, VAR_KEYWORD)
+
+        args_helper = list(params_helper.items())
+
+        pos_helper = 0
+        for nt, pt in params_target.items():
+            kt = pt.kind
+            if kt in (POSITIONAL_ONLY, POSITIONAL_OR_KEYWORD):
+                assert pos_helper < len(args_helper), (
+                    "helper's signature is too short; "
+                    "some arguments are not properly re-exposed"
+                )
+                nh, ph = args_helper[pos_helper]
+                if (kh := ph.kind) is not VAR_POSITIONAL:
+                    assert nh == nt, f"argument {nt!r} isn't re-exposed as positional"
+                    assert kh is kt, (
+                        f"helper is not re-exposing argument {nt!r} properly:"
+                        f"expected {kt}, got {kh}"
+                    )
+                    pos_helper += 1
+                    continue
+
+            if kt in (KEYWORD_ONLY, POSITIONAL_OR_KEYWORD):
+                if nt in params_helper:
+                    kh = params_helper[nt].kind
+                    assert kh is kt, (
+                        f"helper is not re-exposing argument {nt!r} properly: "
+                        f"expected {kt}, got {kh}"
+                    )
+                elif kt is KEYWORD_ONLY:
+                    assert (
+                        have_kwargs_helper
+                    ), f"argument {nt!r} is not re-exposed as keyword"
+                elif kt is POSITIONAL_OR_KEYWORD:
+                    assert (
+                        have_args_helper and have_kwargs_helper
+                    ), f"argument {nt!r} is not re-exposed as positional-or-keyword"
+            elif kt is VAR_POSITIONAL:
+                assert have_args_helper, "helper is missing a catch-all *args argument"
+            elif kt is VAR_KEYWORD:
+                assert (
+                    have_kwargs_helper
+                ), "helper is missing a catch-all **kwargs argument"
+
+    def test_known_arguments(self, target, helper):
+        # validate that all exposed arguments map to something in the target
+        try:
+            sig_target = inspect.signature(target)
+        except ValueError:
+            pytest.skip("Non Python function cannot be inspected at runtime")
+
+        params_target = sig_target.parameters
+        sig_helper = inspect.signature(helper)
+        params_helper = sig_helper.parameters
+
+        for kind in (POSITIONAL_ONLY, POSITIONAL_OR_KEYWORD):
+            args_target = self.get_param_group(params_helper, [kind])
+            args_helper = self.get_param_group(params_helper, [kind])
+
+            if (nhelper := len(args_helper)) > (ntarget := len(args_target)):
+                unknown: list[str] = args_helper[ntarget:]
+                raise AssertionError(
+                    f"Found unknown {kind} parameter(s) "
+                    "in helper's signature: "
+                    f"{unknown}, at position(s) {list(range(ntarget, nhelper))}"
+                )
+
+        # keyword-allowed
+        keyword_allowed_target = set(
+            self.get_param_group(params_target, [KEYWORD_ONLY, POSITIONAL_OR_KEYWORD])
+        )
+        keyword_allowed_helper = set(
+            self.get_param_group(params_helper, [KEYWORD_ONLY, POSITIONAL_OR_KEYWORD])
+        )
+
+        # additional private keyword-only argument are allowed because
+        # they are only intended for testing purposes.
+        # For instance, quantile has such a parameter '_q_unit'
+        keyword_allowed_helper = {
+            name for name in keyword_allowed_helper if not name.startswith("_")
+        }
+
+        diff = keyword_allowed_helper - keyword_allowed_target
+        assert not diff, (
+            "Found some keyword-allowed parameters in helper "
+            f"that are unknown to target: {diff}"
+        )
+
+        # finally, check that default values are correctly replicated
+        for name, ph in params_helper.items():
+            if name not in params_target:
+                # In a few cases, the helper defines names that are not in
+                # the target (e.g., a private name like _q_unit in quantile,
+                # or a *args, **kwargs that captures further arguments
+                # that do not matter. We let such cases slip by.
+                continue
+            pt = params_target[name]
+            assert ph.default == pt.default, (
+                f"Default value mismatch for argument {name!r}. "
+                f"Helper has {ph.default!r}, target has {pt.default!r}"
+            )
