@@ -16,7 +16,6 @@ import re
 import shutil
 import tempfile
 from importlib.metadata import version
-from pathlib import Path
 
 import numpy as np
 import pytest
@@ -851,30 +850,6 @@ def test_unyt_array_pickle():
 SYMPY_VERSION = Version(version("sympy"))
 
 
-@pytest.mark.xfail(
-    condition=(SYMPY_VERSION == Version("1.12")),
-    reason="regression in sympy 1.12",
-    raises=AssertionError,
-    strict=True,
-)
-@pytest.mark.xfail(
-    condition=(SYMPY_VERSION in (Version("1.9"), Version("1.10"))),
-    reason="Not resolved upstream as of sympy 1.10",
-    raises=AttributeError,
-    strict=True,
-)
-def test_unpickling_old_array():
-    # see https://github.com/sympy/sympy/issues/22241
-    # the expected error is "AttributeError: 'One' object has no attribute '__dict__'"
-    PFILE = Path(__file__).parent / "data" / "unyt_array_sympy1.8.pickle"
-    with open(PFILE, "rb") as fh:
-        arr = pickle.load(fh)
-
-    # this comparison fails with sympy==1.12
-    # see https://github.com/sympy/sympy/issues/25134
-    assert arr.units.dimensions == cm.dimensions
-
-
 def test_copy():
     quan = unyt_quantity(1, "g")
     arr = unyt_array([1, 2, 3], "cm")
@@ -1546,7 +1521,8 @@ def test_h5_io():
 
     reg.add("code_length", 10.0, dimensions.length)
 
-    warr = unyt_array(np.random.random((256, 256)), "code_length", registry=reg)
+    rng = np.random.default_rng()
+    warr = unyt_array(rng.random((256, 256)), "code_length", registry=reg)
 
     warr.write_hdf5("test.h5")
 
@@ -1565,8 +1541,8 @@ def test_h5_io():
 
     # test code to overwrite existing dataset with data that has a different
     # shape
-
-    warr = unyt_array(np.random.random((255, 255)), "code_length", registry=reg)
+    rng = np.random.default_rng()
+    warr = unyt_array(rng.random((255, 255)), "code_length", registry=reg)
 
     warr.write_hdf5("test.h5")
 
@@ -2165,9 +2141,10 @@ def test_loadtxt_and_savetxt():
     curdir = os.getcwd()
     os.chdir(tmpdir)
 
-    a = unyt_array(np.random.random(10), "kpc")
-    b = unyt_array(np.random.random(10), "Msun")
-    c = unyt_array(np.random.random(10), "km/s")
+    rng = np.random.default_rng()
+    a = unyt_array(rng.random(10), "kpc")
+    b = unyt_array(rng.random(10), "Msun")
+    c = unyt_array(rng.random(10), "km/s")
 
     savetxt("arrays.dat", [a, b, c], delimiter=",")
 
@@ -2221,8 +2198,9 @@ def test_loadtxt_and_savetxt():
 
 
 def test_trig_ufunc_degrees():
+    rng = np.random.default_rng()
     for ufunc in (np.sin, np.cos, np.tan):
-        degree_values = np.random.random(10) * degree
+        degree_values = rng.random(10) * degree
         radian_values = degree_values.in_units("radian")
         assert_array_equal(ufunc(degree_values), ufunc(radian_values))
 
